@@ -161,7 +161,7 @@ class Payment(MuviBase):
             'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
             'payment_type': 'single',
-            'establishment_name': self.merchant_name,
+            'establishment_name': self.merchant_name if 'establishment_name' not in payment_data else payment_data['establishment_name'],
             'sub_payments': [],
             'amount': total_amount, # En cualquier tipo de payment
             'installments': installments,
